@@ -4,20 +4,19 @@ from .auth import *
 
 from .actions import execute_js, redirect
 from .version import check_version as _check_version
-from .socket import initialize as _initialize_socket
+from .socket import initialize as _initialize_socket, url_params
 from .overloads import initialize as _initialize_overloads
 from .list_item_schema import ListItemSchema
 from .page import Page
+from .step import run_steps
 from . import environments as envs
-from .parameters import url_params
+from .generated.inputs import *
+from .generated.outputs import *
 
-environment = os.getenv("ENV")
+ENV = os.getenv("ENV")
+RUNNER = os.getenv("RUNNER")
 
-if environment != envs.AUTOMATION_PROCESS:
-    from .generated.inputs import *
-    from .generated.outputs import *
-
-if environment not in [envs.AUTOMATION_PROCESS, envs.TEST]:
+if not (ENV in [envs.TEST] or RUNNER in ["dash", "hook", "job"]):
     _check_version()
     _initialize_socket()
     _initialize_overloads()
